from django.db import models
from django.core.validators import MinValueValidator, MaxValueValidator
from django.urls import reverse
import datetime


class Author(models.Model):
    first_name = models.CharField(max_length=100, default='')
    last_name = models.CharField(max_length=100, default='')
    age = models.PositiveSmallIntegerField(default='0')
    nationality = models.CharField(max_length=100, default='')
    bio = models.TextField(max_length=700, default='')

    def __str__(self):
        return '{} {}'.format(self.first_name, self.last_name)
    
    def get_absolute_url(self):
        return reverse('bookshelf:authors-detail', kwargs={'pk': self.pk})
    

class Books(models.Model):
    title = models.CharField(max_length=255, default='')
    author = models.ForeignKey(Author, on_delete=models.CASCADE)
    publisher = models.CharField(max_length=100, default='')
    YEAR_PUBLISHED_CHOICES = [(r,r) for r in range(1454, datetime.date.today().year+1)]
    year_published = models.PositiveIntegerField(choices=YEAR_PUBLISHED_CHOICES,
    default=datetime.datetime.today().year)
    ISBN = models.PositiveIntegerField(
        validators=[MaxValueValidator(9999999999999),
                    MinValueValidator(0000000000000)],
                    default=1000000000000)
    blurb = models.TextField(default='')

    def __str__(self):
        return '{} by {}, {}'.format(self.title, self.author, self.year_published)
    
    def get_absolute_url(self):
        return reverse('bookshelf:books-detail', kwargs={'pk': self.pk})
    